@@ -346,9 +346,11 @@ def mtConn():
         output = render(
             "Moscow Time", colors=['yellow'], align='left', font='tiny'
         )
-
+        outputT = render(
+            a + " sats", colors=['green'], align='left', font='tiny'
+        )
         print(output)
-        print(a)
+        print(outputT)
         input("\a\nContinue...")
     except:
         pass
